import datetime

from eolymp.annotations import mcp_pb2 as _mcp_pb2
from eolymp.mail import email_type_pb2 as _email_type_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class User(_message.Message):
    __slots__ = ("issuer", "subject", "nickname", "nickname_change_timeout", "aliases", "email", "email_verified", "email_restricted", "email_subscriptions", "password", "password_age", "name", "picture", "birthday", "country", "city", "team_id", "preferences")
    class Preferences(_message.Message):
        __slots__ = ("locale", "timezone", "runtime")
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        TIMEZONE_FIELD_NUMBER: _ClassVar[int]
        RUNTIME_FIELD_NUMBER: _ClassVar[int]
        locale: str
        timezone: str
        runtime: str
        def __init__(self, locale: _Optional[str] = ..., timezone: _Optional[str] = ..., runtime: _Optional[str] = ...) -> None: ...
    class Alias(_message.Message):
        __slots__ = ("nickname", "changed_at")
        NICKNAME_FIELD_NUMBER: _ClassVar[int]
        CHANGED_AT_FIELD_NUMBER: _ClassVar[int]
        nickname: str
        changed_at: _timestamp_pb2.Timestamp
        def __init__(self, nickname: _Optional[str] = ..., changed_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    ISSUER_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    NICKNAME_FIELD_NUMBER: _ClassVar[int]
    NICKNAME_CHANGE_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    ALIASES_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    EMAIL_VERIFIED_FIELD_NUMBER: _ClassVar[int]
    EMAIL_RESTRICTED_FIELD_NUMBER: _ClassVar[int]
    EMAIL_SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_AGE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PICTURE_FIELD_NUMBER: _ClassVar[int]
    BIRTHDAY_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    CITY_FIELD_NUMBER: _ClassVar[int]
    TEAM_ID_FIELD_NUMBER: _ClassVar[int]
    PREFERENCES_FIELD_NUMBER: _ClassVar[int]
    issuer: str
    subject: str
    nickname: str
    nickname_change_timeout: int
    aliases: _containers.RepeatedCompositeFieldContainer[User.Alias]
    email: str
    email_verified: bool
    email_restricted: bool
    email_subscriptions: _containers.RepeatedScalarFieldContainer[_email_type_pb2.EmailType]
    password: str
    password_age: int
    name: str
    picture: str
    birthday: _timestamp_pb2.Timestamp
    country: str
    city: str
    team_id: str
    preferences: User.Preferences
    def __init__(self, issuer: _Optional[str] = ..., subject: _Optional[str] = ..., nickname: _Optional[str] = ..., nickname_change_timeout: _Optional[int] = ..., aliases: _Optional[_Iterable[_Union[User.Alias, _Mapping]]] = ..., email: _Optional[str] = ..., email_verified: bool = ..., email_restricted: bool = ..., email_subscriptions: _Optional[_Iterable[_Union[_email_type_pb2.EmailType, str]]] = ..., password: _Optional[str] = ..., password_age: _Optional[int] = ..., name: _Optional[str] = ..., picture: _Optional[str] = ..., birthday: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., country: _Optional[str] = ..., city: _Optional[str] = ..., team_id: _Optional[str] = ..., preferences: _Optional[_Union[User.Preferences, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ShippingMethod(_message.Message):
    __slots__ = ("id", "name", "cost", "min_order_value")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    COST_FIELD_NUMBER: _ClassVar[int]
    MIN_ORDER_VALUE_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    cost: int
    min_order_value: int
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., cost: _Optional[int] = ..., min_order_value: _Optional[int] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.vendor import profile_pb2 as _profile_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeProfileInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeProfileOutput(_message.Message):
    __slots__ = ("profile",)
    PROFILE_FIELD_NUMBER: _ClassVar[int]
    profile: _profile_pb2.Profile
    def __init__(self, profile: _Optional[_Union[_profile_pb2.Profile, _Mapping]] = ...) -> None: ...

class UpdateProfileInput(_message.Message):
    __slots__ = ("patch", "profile")
    PATCH_FIELD_NUMBER: _ClassVar[int]
    PROFILE_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[_profile_pb2.Profile.Patch.Field]
    profile: _profile_pb2.Profile
    def __init__(self, patch: _Optional[_Iterable[_Union[_profile_pb2.Profile.Patch.Field, str]]] = ..., profile: _Optional[_Union[_profile_pb2.Profile, _Mapping]] = ...) -> None: ...

class UpdateProfileOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SubmitProfileInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SubmitProfileOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/vendor/payment_method_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/vendor/payment_method_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.vendor import payment_method_pb2 as eolymp_dot_vendor_dot_payment__method__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*eolymp/vendor/payment_method_service.proto\x12\reolymp.vendor\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/vendor/payment_method.proto\x1a!eolymp/wellknown/expression.proto\"H\n\x18\x43reatePaymentMethodInput\x12,\n\x06method\x18\x01 \x01(\x0b\x32\x1c.eolymp.vendor.PaymentMethod\".\n\x19\x43reatePaymentMethodOutput\x12\x11\n\tmethod_id\x18\x01 \x01(\t\"[\n\x18UpdatePaymentMethodInput\x12\x11\n\tmethod_id\x18\x01 \x01(\t\x12,\n\x06method\x18\x02 \x01(\x0b\x32\x1c.eolymp.vendor.PaymentMethod\"\x1b\n\x19UpdatePaymentMethodOutput\"-\n\x18\x44\x65letePaymentMethodInput\x12\x11\n\tmethod_id\x18\x01 \x01(\t\"\x1b\n\x19\x44\x65letePaymentMethodOutput\"/\n\x1a\x44\x65scribePaymentMethodInput\x12\x11\n\tmethod_id\x18\x01 \x01(\t\"K\n\x1b\x44\x65scribePaymentMethodOutput\x12,\n\x06method\x18\x01 \x01(\x0b\x32\x1c.eolymp.vendor.PaymentMethod\"\xcc\x01\n\x17ListPaymentMethodsInput\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.vendor.ListPaymentMethodsInput.Filter\x1a\x34\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"V\n\x18ListPaymentMethodsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12+\n\x05items\x18\x02 \x03(\x0b\x32\x1c.eolymp.vendor.PaymentMethod2\xce\x07\n\x14PaymentMethodService\x12\xb4\x01\n\x13\x43reatePaymentMethod\x12\'.eolymp.vendor.CreatePaymentMethodInput\x1a(.eolymp.vendor.CreatePaymentMethodOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02\x19\"\x17/vendor/payment-methods\x12\xc0\x01\n\x13UpdatePaymentMethod\x12\'.eolymp.vendor.UpdatePaymentMethodInput\x1a(.eolymp.vendor.UpdatePaymentMethodOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02%\"#/vendor/payment-methods/{method_id}\x12\xc0\x01\n\x13\x44\x65letePaymentMethod\x12\'.eolymp.vendor.DeletePaymentMethodInput\x1a(.eolymp.vendor.DeletePaymentMethodOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02%*#/vendor/payment-methods/{method_id}\x12\xc5\x01\n\x15\x44\x65scribePaymentMethod\x12).eolymp.vendor.DescribePaymentMethodInput\x1a*.eolymp.vendor.DescribePaymentMethodOutput\"U\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x17\x8a\xe3\n\x13vendor:profile:read\x82\xd3\xe4\x93\x02%\x12#/vendor/payment-methods/{method_id}\x12\xb0\x01\n\x12ListPaymentMethods\x12&.eolymp.vendor.ListPaymentMethodsInput\x1a\'.eolymp.vendor.ListPaymentMethodsOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x17\x8a\xe3\n\x13vendor:profile:read\x82\xd3\xe4\x93\x02\x19\x12\x17/vendor/payment-methodsB/Z-github.com/eolymp/go-sdk/eolymp/vendor;vendorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.vendor.payment_method_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/vendor;vendor'
  _globals['_PAYMENTMETHODSERVICE'].methods_by_name['CreatePaymentMethod']._loaded_options = None
  _globals['_PAYMENTMETHODSERVICE'].methods_by_name['CreatePaymentMethod']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002\031\"\027/vendor/payment-methods'
  _globals['_PAYMENTMETHODSERVICE'].methods_by_name['UpdatePaymentMethod']._loaded_options = None
  _globals['_PAYMENTMETHODSERVICE'].methods_by_name['UpdatePaymentMethod']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002%\"#/vendor/payment-methods/{method_id}'
  _globals['_PAYMENTMETHODSERVICE'].methods_by_name['DeletePaymentMethod']._loaded_options = None
  _globals['_PAYMENTMETHODSERVICE'].methods_by_name['DeletePaymentMethod']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002%*#/vendor/payment-methods/{method_id}'
  _globals['_PAYMENTMETHODSERVICE'].methods_by_name['DescribePaymentMethod']._loaded_options = None
  _globals['_PAYMENTMETHODSERVICE'].methods_by_name['DescribePaymentMethod']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\027\212\343\n\023vendor:profile:read\202\323\344\223\002%\022#/vendor/payment-methods/{method_id}'
  _globals['_PAYMENTMETHODSERVICE'].methods_by_name['ListPaymentMethods']._loaded_options = None
  _globals['_PAYMENTMETHODSERVICE'].methods_by_name['ListPaymentMethods']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\027\212\343\n\023vendor:profile:read\202\323\344\223\002\031\022\027/vendor/payment-methods'
  _globals['_CREATEPAYMENTMETHODINPUT']._serialized_start=231
  _globals['_CREATEPAYMENTMETHODINPUT']._serialized_end=303
  _globals['_CREATEPAYMENTMETHODOUTPUT']._serialized_start=305
  _globals['_CREATEPAYMENTMETHODOUTPUT']._serialized_end=351
  _globals['_UPDATEPAYMENTMETHODINPUT']._serialized_start=353
  _globals['_UPDATEPAYMENTMETHODINPUT']._serialized_end=444
  _globals['_UPDATEPAYMENTMETHODOUTPUT']._serialized_start=446
  _globals['_UPDATEPAYMENTMETHODOUTPUT']._serialized_end=473
  _globals['_DELETEPAYMENTMETHODINPUT']._serialized_start=475
  _globals['_DELETEPAYMENTMETHODINPUT']._serialized_end=520
  _globals['_DELETEPAYMENTMETHODOUTPUT']._serialized_start=522
  _globals['_DELETEPAYMENTMETHODOUTPUT']._serialized_end=549
  _globals['_DESCRIBEPAYMENTMETHODINPUT']._serialized_start=551
  _globals['_DESCRIBEPAYMENTMETHODINPUT']._serialized_end=598
  _globals['_DESCRIBEPAYMENTMETHODOUTPUT']._serialized_start=600
  _globals['_DESCRIBEPAYMENTMETHODOUTPUT']._serialized_end=675
  _globals['_LISTPAYMENTMETHODSINPUT']._serialized_start=678
  _globals['_LISTPAYMENTMETHODSINPUT']._serialized_end=882
  _globals['_LISTPAYMENTMETHODSINPUT_FILTER']._serialized_start=830
  _globals['_LISTPAYMENTMETHODSINPUT_FILTER']._serialized_end=882
  _globals['_LISTPAYMENTMETHODSOUTPUT']._serialized_start=884
  _globals['_LISTPAYMENTMETHODSOUTPUT']._serialized_end=970
  _globals['_PAYMENTMETHODSERVICE']._serialized_start=973
  _globals['_PAYMENTMETHODSERVICE']._serialized_end=1947
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/credit_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/credit_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import namespace_pb2 as eolymp_dot_annotations_dot_namespace__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import credit_pb2 as eolymp_dot_community_dot_credit__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/community/credit_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/namespace.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/community/credit.proto\x1a!eolymp/wellknown/expression.proto\"\x16\n\x14\x44\x65scribeBalanceInput\"(\n\x15\x44\x65scribeBalanceOutput\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\r\"A\n\x10GrantCreditInput\x12-\n\x05grant\x18\x01 \x01(\x0b\x32\x1e.eolymp.community.Credit.Grant\"=\n\x11GrantCreditOutput\x12\x10\n\x08grant_id\x18\x01 \x01(\t\x12\x16\n\x0etransaction_id\x18\x02 \x01(\t\"%\n\x11\x43\x61ncelCreditInput\x12\x10\n\x08grant_id\x18\x01 \x01(\t\"\x14\n\x12\x43\x61ncelCreditOutput\"\xf5\x02\n\x15ListCreditGrantsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12?\n\x07\x66ilters\x18( \x01(\x0b\x32..eolymp.community.ListCreditGrantsInput.Filter\x1a\xfc\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\treference\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04note\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12/\n\x06\x61mount\x18\x04 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12\x30\n\x06\x61\x63tive\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"V\n\x16ListCreditGrantsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12-\n\x05items\x18\x02 \x03(\x0b\x32\x1e.eolymp.community.Credit.Grant\"D\n\x11RedeemCreditInput\x12\x0e\n\x06\x61mount\x18\x01 \x01(\r\x12\x11\n\treference\x18\x02 \x01(\t\x12\x0c\n\x04note\x18\x03 \x01(\t\",\n\x12RedeemCreditOutput\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\"\xb8\x01\n\x1bListCreditTransactionsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x45\n\x07\x66ilters\x18( \x01(\x0b\x32\x34.eolymp.community.ListCreditTransactionsInput.Filter\x1a\x34\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"b\n\x1cListCreditTransactionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x33\n\x05items\x18\x02 \x03(\x0b\x32$.eolymp.community.Credit.Transaction\";\n\x11RefundCreditInput\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\r\"\x14\n\x12RefundCreditOutput2\xec\t\n\rCreditService\x12\xa7\x01\n\x0f\x44\x65scribeBalance\x12&.eolymp.community.DescribeBalanceInput\x1a\'.eolymp.community.DescribeBalanceOutput\"C\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:credit:read\x82\xd3\xe4\x93\x02\x11\x12\x0f/credit/balance\x12\x9b\x01\n\x0bGrantCredit\x12\".eolymp.community.GrantCreditInput\x1a#.eolymp.community.GrantCreditOutput\"C\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:credit:write\x82\xd3\xe4\x93\x02\x10\"\x0e/credit/grants\x12\xa9\x01\n\x0c\x43\x61ncelCredit\x12#.eolymp.community.CancelCreditInput\x1a$.eolymp.community.CancelCreditOutput\"N\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:credit:write\x82\xd3\xe4\x93\x02\x1b*\x19/credit/grants/{grant_id}\x12\xa9\x01\n\x10ListCreditGrants\x12\'.eolymp.community.ListCreditGrantsInput\x1a(.eolymp.community.ListCreditGrantsOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:credit:read\x82\xd3\xe4\x93\x02\x10\x12\x0e/credit/grants\x12\x9e\x01\n\x0cRedeemCredit\x12#.eolymp.community.RedeemCreditInput\x1a$.eolymp.community.RedeemCreditOutput\"C\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:credit:write\x82\xd3\xe4\x93\x02\x10\"\x0e/credit/redeem\x12\xbb\x01\n\x16ListCreditTransactions\x12-.eolymp.community.ListCreditTransactionsInput\x1a..eolymp.community.ListCreditTransactionsOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:credit:read\x82\xd3\xe4\x93\x02\x10\x12\x0e/credit/grants\x12\xbc\x01\n\x0cRefundCredit\x12#.eolymp.community.RefundCreditInput\x1a$.eolymp.community.RefundCreditOutput\"a\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:credit:write\x82\xd3\xe4\x93\x02.\",/credit/transactions/{transaction_id}/refund\x1a\x1d\x82\xf0\xf0\xe4\x01\x17\x65olymp.community.MemberB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.credit_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_CREDITSERVICE']._loaded_options = None
  _globals['_CREDITSERVICE']._serialized_options = b'\202\360\360\344\001\027eolymp.community.Member'
  _globals['_CREDITSERVICE'].methods_by_name['DescribeBalance']._loaded_options = None
  _globals['_CREDITSERVICE'].methods_by_name['DescribeBalance']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\031\212\343\n\025community:credit:read\202\323\344\223\002\021\022\017/credit/balance'
  _globals['_CREDITSERVICE'].methods_by_name['GrantCredit']._loaded_options = None
  _globals['_CREDITSERVICE'].methods_by_name['GrantCredit']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\032\212\343\n\026community:credit:write\202\323\344\223\002\020\"\016/credit/grants'
  _globals['_CREDITSERVICE'].methods_by_name['CancelCredit']._loaded_options = None
  _globals['_CREDITSERVICE'].methods_by_name['CancelCredit']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\032\212\343\n\026community:credit:write\202\323\344\223\002\033*\031/credit/grants/{grant_id}'
  _globals['_CREDITSERVICE'].methods_by_name['ListCreditGrants']._loaded_options = None
  _globals['_CREDITSERVICE'].methods_by_name['ListCreditGrants']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\031\212\343\n\025community:credit:read\202\323\344\223\002\020\022\016/credit/grants'
  _globals['_CREDITSERVICE'].methods_by_name['RedeemCredit']._loaded_options = None
  _globals['_CREDITSERVICE'].methods_by_name['RedeemCredit']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\032\212\343\n\026community:credit:write\202\323\344\223\002\020\"\016/credit/redeem'
  _globals['_CREDITSERVICE'].methods_by_name['ListCreditTransactions']._loaded_options = None
  _globals['_CREDITSERVICE'].methods_by_name['ListCreditTransactions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\031\212\343\n\025community:credit:read\202\323\344\223\002\020\022\016/credit/grants'
  _globals['_CREDITSERVICE'].methods_by_name['RefundCredit']._loaded_options = None
  _globals['_CREDITSERVICE'].methods_by_name['RefundCredit']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\032\212\343\n\026community:credit:write\202\323\344\223\002.\",/credit/transactions/{transaction_id}/refund'
  _globals['_DESCRIBEBALANCEINPUT']._serialized_start=260
  _globals['_DESCRIBEBALANCEINPUT']._serialized_end=282
  _globals['_DESCRIBEBALANCEOUTPUT']._serialized_start=284
  _globals['_DESCRIBEBALANCEOUTPUT']._serialized_end=324
  _globals['_GRANTCREDITINPUT']._serialized_start=326
  _globals['_GRANTCREDITINPUT']._serialized_end=391
  _globals['_GRANTCREDITOUTPUT']._serialized_start=393
  _globals['_GRANTCREDITOUTPUT']._serialized_end=454
  _globals['_CANCELCREDITINPUT']._serialized_start=456
  _globals['_CANCELCREDITINPUT']._serialized_end=493
  _globals['_CANCELCREDITOUTPUT']._serialized_start=495
  _globals['_CANCELCREDITOUTPUT']._serialized_end=515
  _globals['_LISTCREDITGRANTSINPUT']._serialized_start=518
  _globals['_LISTCREDITGRANTSINPUT']._serialized_end=891
  _globals['_LISTCREDITGRANTSINPUT_FILTER']._serialized_start=639
  _globals['_LISTCREDITGRANTSINPUT_FILTER']._serialized_end=891
  _globals['_LISTCREDITGRANTSOUTPUT']._serialized_start=893
  _globals['_LISTCREDITGRANTSOUTPUT']._serialized_end=979
  _globals['_REDEEMCREDITINPUT']._serialized_start=981
  _globals['_REDEEMCREDITINPUT']._serialized_end=1049
  _globals['_REDEEMCREDITOUTPUT']._serialized_start=1051
  _globals['_REDEEMCREDITOUTPUT']._serialized_end=1095
  _globals['_LISTCREDITTRANSACTIONSINPUT']._serialized_start=1098
  _globals['_LISTCREDITTRANSACTIONSINPUT']._serialized_end=1282
  _globals['_LISTCREDITTRANSACTIONSINPUT_FILTER']._serialized_start=639
  _globals['_LISTCREDITTRANSACTIONSINPUT_FILTER']._serialized_end=691
  _globals['_LISTCREDITTRANSACTIONSOUTPUT']._serialized_start=1284
  _globals['_LISTCREDITTRANSACTIONSOUTPUT']._serialized_end=1382
  _globals['_REFUNDCREDITINPUT']._serialized_start=1384
  _globals['_REFUNDCREDITINPUT']._serialized_end=1443
  _globals['_REFUNDCREDITOUTPUT']._serialized_start=1445
  _globals['_REFUNDCREDITOUTPUT']._serialized_end=1465
  _globals['_CREDITSERVICE']._serialized_start=1468
  _globals['_CREDITSERVICE']._serialized_end=2728
# @@protoc_insertion_point(module_scope)



from .vendor_service_pb2 import *
from .profile_service_pb2 import *
from .vendor_service_http import *
from .invoice_service_http import *
from .invoice_service_pb2 import *
from .profile_service_http import *
from .profile_pb2 import *
from .payment_method_pb2 import *
from .payment_method_service_pb2 import *
from .invoice_pb2 import *
from .payment_method_service_http import *



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/auth/client_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/auth/client_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.auth import client_pb2 as eolymp_dot_auth_dot_client__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/auth/client_service.proto\x12\x0b\x65olymp.auth\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x18\x65olymp/auth/client.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"0\n\x10ListClientsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"F\n\x11ListClientsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\"\n\x05items\x18\x02 \x03(\x0b\x32\x13.eolymp.auth.Client\"(\n\x13\x44\x65scribeClientInput\x12\x11\n\tclient_id\x18\x01 \x01(\t\";\n\x14\x44\x65scribeClientOutput\x12#\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x13.eolymp.auth.Client\"8\n\x11\x43reateClientInput\x12#\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x13.eolymp.auth.Client\"7\n\x12\x43reateClientOutput\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"{\n\x11UpdateClientInput\x12.\n\x05patch\x18\x01 \x03(\x0e\x32\x1f.eolymp.auth.Client.Patch.Field\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12#\n\x06\x63lient\x18\x03 \x01(\x0b\x32\x13.eolymp.auth.Client\"\x14\n\x12UpdateClientOutput\"&\n\x11\x44\x65leteClientInput\x12\x11\n\tclient_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteClientOutput\"+\n\x16ResetClientSecretInput\x12\x11\n\tclient_id\x18\x01 \x01(\t\")\n\x17ResetClientSecretOutput\x12\x0e\n\x06secret\x18\x01 \x01(\t\"\xdb\x02\n\x13RegisterClientInput\x12\x15\n\rredirect_uris\x18\x01 \x03(\t\x12\"\n\x1atoken_endpoint_auth_method\x18\x02 \x01(\t\x12\x13\n\x0bgrant_types\x18\x03 \x03(\t\x12\x16\n\x0eresponse_types\x18\x04 \x03(\t\x12\x13\n\x0b\x63lient_name\x18\x05 \x01(\t\x12\x12\n\nclient_uri\x18\x06 \x01(\t\x12\x10\n\x08logo_uri\x18\x07 \x01(\t\x12\r\n\x05scope\x18\x08 \x01(\t\x12\x10\n\x08\x63ontacts\x18\t \x03(\t\x12\x0f\n\x07tos_uri\x18\n \x01(\t\x12\x12\n\npolicy_uri\x18\x0b \x01(\t\x12\x10\n\x08jwks_uri\x18\x0c \x01(\t\x12\x13\n\x0bsoftware_id\x18\r \x01(\t\x12\x18\n\x10software_version\x18\x0e \x01(\t\x12\x1a\n\x12software_statement\x18\x64 \x01(\t\"\xb8\x04\n\x14RegisterClientOutput\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x15\n\rclient_secret\x18\x02 \x01(\t\x12\x37\n\x13\x63lient_id_issued_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x18\x63lient_secret_expires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\x19registration_access_token\x18\x05 \x01(\t\x12\x1f\n\x17registration_client_uri\x18\x06 \x01(\t\x12\"\n\x1atoken_endpoint_auth_method\x18\x07 \x01(\t\x12\x18\n\x10\x61pplication_type\x18\x08 \x01(\t\x12\x15\n\rredirect_uris\x18\t \x03(\t\x12\x13\n\x0b\x63lient_name\x18\n \x01(\t\x12\x10\n\x08logo_uri\x18\x0b \x01(\t\x12\x14\n\x0csubject_type\x18\x0c \x01(\t\x12\x1d\n\x15sector_identifier_uri\x18\r \x01(\t\x12\x10\n\x08jwks_uri\x18\x0e \x01(\t\x12\'\n\x1fuserinfo_encrypted_response_alg\x18\x0f \x01(\t\x12\'\n\x1fuserinfo_encrypted_response_enc\x18\x10 \x01(\t\x12\x10\n\x08\x63ontacts\x18\x11 \x03(\t\x12\x14\n\x0crequest_uris\x18\x12 \x03(\t2\xc9\x08\n\rClientService\x12\x8a\x01\n\x0bListClients\x12\x1d.eolymp.auth.ListClientsInput\x1a\x1e.eolymp.auth.ListClientsOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x14\x8a\xe3\n\x10\x61uth:client:read\x82\xd3\xe4\x93\x02\x0f\x12\r/auth/clients\x12\x9f\x01\n\x0e\x44\x65scribeClient\x12 .eolymp.auth.DescribeClientInput\x1a!.eolymp.auth.DescribeClientOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x14\x8a\xe3\n\x10\x61uth:client:read\x82\xd3\xe4\x93\x02\x1b\x12\x19/auth/clients/{client_id}\x12\x8e\x01\n\x0c\x43reateClient\x12\x1e.eolymp.auth.CreateClientInput\x1a\x1f.eolymp.auth.CreateClientOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x15\x8a\xe3\n\x11\x61uth:client:write\x82\xd3\xe4\x93\x02\x0f\"\r/auth/clients\x12\x9a\x01\n\x0cUpdateClient\x12\x1e.eolymp.auth.UpdateClientInput\x1a\x1f.eolymp.auth.UpdateClientOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x15\x8a\xe3\n\x11\x61uth:client:write\x82\xd3\xe4\x93\x02\x1b\x1a\x19/auth/clients/{client_id}\x12\x9a\x01\n\x0c\x44\x65leteClient\x12\x1e.eolymp.auth.DeleteClientInput\x1a\x1f.eolymp.auth.DeleteClientOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x15\x8a\xe3\n\x11\x61uth:client:write\x82\xd3\xe4\x93\x02\x1b*\x19/auth/clients/{client_id}\x12\xb6\x01\n\x11ResetClientSecret\x12#.eolymp.auth.ResetClientSecretInput\x1a$.eolymp.auth.ResetClientSecretOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x15\x8a\xe3\n\x11\x61uth:client:write\x82\xd3\xe4\x93\x02(\"&/auth/clients/{client_id}/reset-secret\x12\x84\x01\n\x0eRegisterClient\x12 .eolymp.auth.RegisterClientInput\x1a!.eolymp.auth.RegisterClientOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00@@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x18\"\x16/auth/clients:registerB+Z)github.com/eolymp/go-sdk/eolymp/auth;authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.auth.client_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/auth;auth'
  _globals['_CLIENTSERVICE'].methods_by_name['ListClients']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['ListClients']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\024\212\343\n\020auth:client:read\202\323\344\223\002\017\022\r/auth/clients'
  _globals['_CLIENTSERVICE'].methods_by_name['DescribeClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['DescribeClient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\024\212\343\n\020auth:client:read\202\323\344\223\002\033\022\031/auth/clients/{client_id}'
  _globals['_CLIENTSERVICE'].methods_by_name['CreateClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['CreateClient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\025\212\343\n\021auth:client:write\202\323\344\223\002\017\"\r/auth/clients'
  _globals['_CLIENTSERVICE'].methods_by_name['UpdateClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['UpdateClient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\025\212\343\n\021auth:client:write\202\323\344\223\002\033\032\031/auth/clients/{client_id}'
  _globals['_CLIENTSERVICE'].methods_by_name['DeleteClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['DeleteClient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\025\212\343\n\021auth:client:write\202\323\344\223\002\033*\031/auth/clients/{client_id}'
  _globals['_CLIENTSERVICE'].methods_by_name['ResetClientSecret']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['ResetClientSecret']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\025\212\343\n\021auth:client:write\202\323\344\223\002(\"&/auth/clients/{client_id}/reset-secret'
  _globals['_CLIENTSERVICE'].methods_by_name['RegisterClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['RegisterClient']._serialized_options = b'\352\342\n\013\365\342\n\000\000@@\370\342\n\n\202\323\344\223\002\030\"\026/auth/clients:register'
  _globals['_LISTCLIENTSINPUT']._serialized_start=207
  _globals['_LISTCLIENTSINPUT']._serialized_end=255
  _globals['_LISTCLIENTSOUTPUT']._serialized_start=257
  _globals['_LISTCLIENTSOUTPUT']._serialized_end=327
  _globals['_DESCRIBECLIENTINPUT']._serialized_start=329
  _globals['_DESCRIBECLIENTINPUT']._serialized_end=369
  _globals['_DESCRIBECLIENTOUTPUT']._serialized_start=371
  _globals['_DESCRIBECLIENTOUTPUT']._serialized_end=430
  _globals['_CREATECLIENTINPUT']._serialized_start=432
  _globals['_CREATECLIENTINPUT']._serialized_end=488
  _globals['_CREATECLIENTOUTPUT']._serialized_start=490
  _globals['_CREATECLIENTOUTPUT']._serialized_end=545
  _globals['_UPDATECLIENTINPUT']._serialized_start=547
  _globals['_UPDATECLIENTINPUT']._serialized_end=670
  _globals['_UPDATECLIENTOUTPUT']._serialized_start=672
  _globals['_UPDATECLIENTOUTPUT']._serialized_end=692
  _globals['_DELETECLIENTINPUT']._serialized_start=694
  _globals['_DELETECLIENTINPUT']._serialized_end=732
  _globals['_DELETECLIENTOUTPUT']._serialized_start=734
  _globals['_DELETECLIENTOUTPUT']._serialized_end=754
  _globals['_RESETCLIENTSECRETINPUT']._serialized_start=756
  _globals['_RESETCLIENTSECRETINPUT']._serialized_end=799
  _globals['_RESETCLIENTSECRETOUTPUT']._serialized_start=801
  _globals['_RESETCLIENTSECRETOUTPUT']._serialized_end=842
  _globals['_REGISTERCLIENTINPUT']._serialized_start=845
  _globals['_REGISTERCLIENTINPUT']._serialized_end=1192
  _globals['_REGISTERCLIENTOUTPUT']._serialized_start=1195
  _globals['_REGISTERCLIENTOUTPUT']._serialized_end=1763
  _globals['_CLIENTSERVICE']._serialized_start=1766
  _globals['_CLIENTSERVICE']._serialized_end=2863
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/contest.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/contest.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import mcp_pb2 as eolymp_dot_annotations_dot_mcp__pb2
from eolymp.runtime import runtime_pb2 as eolymp_dot_runtime_dot_runtime__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/judge/contest.proto\x12\x0c\x65olymp.judge\x1a\x1c\x65olymp/annotations/mcp.proto\x1a\x1c\x65olymp/runtime/runtime.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfb\"\n\x07\x43ontest\x12\x12\n\x02id\x18\x01 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x13\n\x03url\x18\x02 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\timage_url\x18\x04 \x01(\t\x12-\n\tstarts_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x65nds_at\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x64uration\x18\x0c \x01(\r\x12\x34\n\x06status\x18\x14 \x01(\x0e\x32\x1c.eolymp.judge.Contest.StatusB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x34\n\nvisibility\x18\x1e \x01(\x0e\x32 .eolymp.judge.Contest.Visibility\x12\x43\n\x12participation_mode\x18\x1f \x01(\x0e\x32\'.eolymp.judge.Contest.ParticipationMode\x12\x19\n\x11join_unofficially\x18! \x01(\x08\x12\x19\n\x11require_admission\x18# \x01(\x08\x12\x13\n\x0b\x61llow_pause\x18$ \x01(\x08\x12\x1a\n\x12\x61llow_finish_early\x18% \x01(\x08\x12\x15\n\rallow_upsolve\x18& \x01(\x08\x12\x16\n\x0e\x61llow_followup\x18\' \x01(\x08\x12\x1a\n\x12\x64isplay_editorials\x18) \x01(\x08\x12,\n\x06\x66ormat\x18  \x01(\x0e\x32\x1c.eolymp.judge.Contest.Format\x12\x0b\n\x03key\x18( \x01(\t\x12\x1d\n\rproblem_count\x18< \x01(\rB\x06\xa8\xf0\xf0\xe4\x01\x01\x12$\n\x14problem_count_hidden\x18= \x01(\x08\x42\x06\xa8\xf0\xf0\xe4\x01\x01\x12!\n\x11participant_count\x18> \x01(\rB\x06\xa8\xf0\xf0\xe4\x01\x01\x12(\n\x18participant_count_hidden\x18? \x01(\x08\x42\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x32\n\x0e\x66\x65\x61tured_until\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\nprinter_id\x18G \x01(\tB\x06\xb0\xf0\xf0\xe4\x01\x01\x12$\n\x1c\x65nable_reminder_notification\x18\r \x01(\x08\x12V\n\x1creminder_notification_status\x18\x0e \x01(\x0e\x32(.eolymp.judge.Contest.NotificationStatusB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\"\n\x1a\x65nable_result_notification\x18\x10 \x01(\x08\x12T\n\x1aresult_notification_status\x18\x11 \x01(\x0e\x32(.eolymp.judge.Contest.NotificationStatusB\x06\xa8\xf0\xf0\xe4\x01\x01\x12<\n\x0e\x63lassification\x18n \x01(\x0b\x32$.eolymp.judge.Contest.Classification\x12\x41\n\x11scoreboard_config\x18i \x01(\x0b\x32&.eolymp.judge.Contest.ScoreboardConfig\x12\x43\n\x12\x65nvironment_config\x18o \x01(\x0b\x32\'.eolymp.judge.Contest.EnvironmentConfig\x12G\n\x14\x63\x65rtification_config\x18p \x01(\x0b\x32).eolymp.judge.Contest.CertificationConfig\x12\x41\n\x11plagiarism_config\x18q \x01(\x0b\x32&.eolymp.judge.Contest.PlagiarismConfig\x12\x39\n\rrating_config\x18r \x01(\x0b\x32\".eolymp.judge.Contest.RatingConfig\x12\x32\n\x05staff\x18x \x03(\x0b\x32\x1b.eolymp.judge.Contest.StaffB\x06\xa8\xf0\xf0\xe4\x01\x01\x1a\xcd\x04\n\x05Patch\"\xc3\x04\n\x05\x46ield\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04NAME\x10\x02\x12\r\n\tIMAGE_URL\x10\x0e\x12\r\n\tSTARTS_AT\x10\x03\x12\x0b\n\x07\x45NDS_AT\x10\x04\x12\x0c\n\x08\x44URATION\x10\x05\x12\x0e\n\nVISIBILITY\x10\x06\x12\x15\n\x11JOIN_UNOFFICIALLY\x10\x07\x12\x16\n\x12PARTICIPATION_MODE\x10\x08\x12\x15\n\x11REQUIRE_ADMISSION\x10\x10\x12\x0f\n\x0b\x41LLOW_PAUSE\x10\x11\x12\x16\n\x12\x41LLOW_FINISH_EARLY\x10\x12\x12\x11\n\rALLOW_UPSOLVE\x10x\x12\x12\n\x0e\x41LLOW_FOLLOWUP\x10y\x12\x16\n\x12\x44ISPLAY_EDITORIALS\x10z\x12\n\n\x06\x46ORMAT\x10\n\x12\x07\n\x03KEY\x10\x0b\x12\x18\n\x14PROBLEM_COUNT_HIDDEN\x10\x0c\x12\x1c\n\x18PARTICIPANT_COUNT_HIDDEN\x10\r\x12\x12\n\x0e\x46\x45\x41TURED_UNTIL\x10\t\x12\x19\n\x15REMINDER_NOTIFICATION\x10\x13\x12\x17\n\x13RESULT_NOTIFICATION\x10\x14\x12\x0b\n\x07PRINTER\x10\x0f\x12\x12\n\x0e\x43LASSIFICATION\x10\x64\x12\x16\n\x11SCOREBOARD_CONFIG\x10\x96\x01\x12\x19\n\x14\x43\x45RTIFICATION_CONFIG\x10\x97\x01\x12\x17\n\x12\x45NVIRONMENT_CONFIG\x10\x98\x01\x12\x16\n\x11PLAGIARISM_CONFIG\x10\x99\x01\x12\x12\n\rRATING_CONFIG\x10\x9a\x01\x1a\xb0\x01\n\x05\x45xtra\"\xa6\x01\n\x05\x46ield\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05STAFF\x10\x05\x12\x12\n\x0e\x43LASSIFICATION\x10\x01\x12\x15\n\x11SCOREBOARD_CONFIG\x10\x02\x12\x18\n\x14\x43\x45RTIFICATION_CONFIG\x10\x03\x12\x16\n\x12\x45NVIRONMENT_CONFIG\x10\x04\x12\x15\n\x11PLAGIARISM_CONFIG\x10\x06\x12\x11\n\rRATING_CONFIG\x10\x07\x1a\x82\x02\n\x0e\x43lassification\x12\x0c\n\x04year\x18\x01 \x01(\r\x12\x0e\n\x06series\x18\x02 \x01(\t\x12\x39\n\x05scale\x18\x03 \x01(\x0e\x32*.eolymp.judge.Contest.Classification.Scale\x12\x12\n\ndifficulty\x18\x04 \x01(\r\x12\x0f\n\x07\x63ountry\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04\x63ity\x18\x07 \x01(\t\"T\n\x05Scale\x12\x11\n\rUNKNOWN_SCALE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08REGIONAL\x10\x02\x12\x0c\n\x08NATIONAL\x10\x03\x12\x11\n\rINTERNATIONAL\x10\x04\x1a\x9b\x03\n\x10ScoreboardConfig\x12\x45\n\nvisibility\x18\x01 \x01(\x0e\x32\x31.eolymp.judge.Contest.ScoreboardConfig.Visibility\x12\x15\n\rfreezing_time\x18\x02 \x01(\r\x12\x16\n\x0eunfreeze_delay\x18\x03 \x01(\x05\x12\x17\n\x0f\x61ttempt_penalty\x18\x04 \x01(\r\x12\x13\n\x0btie_breaker\x18\x05 \x01(\t\x12\x15\n\rno_spoiler_ui\x18\x06 \x01(\x08\x12\x11\n\tshare_key\x18\x07 \x01(\t\"\xb8\x01\n\nVisibility\x12\x16\n\x12UNKNOWN_VISIBILITY\x10\x00\x12/\n\tINVISIBLE\x10\x01\x1a \x9a\xf0\xf0\xe4\x01\x1avisible only to organizers\x12:\n\x08INTERNAL\x10\x02\x1a,\x9a\xf0\xf0\xe4\x01&visible to participants and organizers\x12%\n\x06PUBLIC\x10\x03\x1a\x19\x9a\xf0\xf0\xe4\x01\x13visible to everyone\x1a\x31\n\x0cRatingConfig\x12\r\n\x05rated\x18\x01 \x01(\x08\x12\x12\n\nmax_rating\x18\x07 \x01(\r\x1a\xa5\x01\n\x13\x43\x65rtificationConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x13\n\x0b\x61\x66\x66iliation\x18\x02 \x01(\t\x12\x41\n\x07signers\x18\x03 \x03(\x0b\x32\x30.eolymp.judge.Contest.CertificationConfig.Signer\x1a%\n\x06Signer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x1a>\n\x11\x45nvironmentConfig\x12)\n\x08runtimes\x18\x02 \x03(\x0b\x32\x17.eolymp.runtime.Runtime\x1a+\n\x10PlagiarismConfig\x12\x17\n\x0f\x63heck_genai_use\x18\x01 \x01(\x08\x1a>\n\x05Staff\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\"\xaf\x03\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12/\n\tSCHEDULED\x10\x01\x1a \x9a\xf0\xf0\xe4\x01\x1a\x63ontest hasn\'t started yet\x12\x41\n\x04OPEN\x10\x02\x1a\x37\x9a\xf0\xf0\xe4\x01\x31\x63ontest has started, participants can participate\x12\'\n\x08\x43OMPLETE\x10\x03\x1a\x19\x9a\xf0\xf0\xe4\x01\x13\x63ontest is finished\x12K\n\tSUSPENDED\x10\x04\x1a<\x9a\xf0\xf0\xe4\x01\x36\x63ontest has been suspended, interface is not available\x12^\n\x06\x46ROZEN\x10\x05\x1aR\x9a\xf0\xf0\xe4\x01Lcontest has been frozen, interface is available but submission is restricted\x12G\n\tFINALIZED\x10\x06\x1a\x38\x9a\xf0\xf0\xe4\x01\x32\x63omplete, results are final and can not be changed\"\xf5\x01\n\nVisibility\x12\x16\n\x12VISIBILITY_UNKNOWN\x10\x00\x12>\n\x06PUBLIC\x10\x01\x1a\x32\x9a\xf0\xf0\xe4\x01,visible to everyone and shown on the website\x12H\n\x08UNLISTED\x10\x02\x1a:\x9a\xf0\xf0\xe4\x01\x34\x61nyone can participate, but not shown on the website\x12\x45\n\x07PRIVATE\x10\x03\x1a\x38\x9a\xf0\xf0\xe4\x01\x32only explicitly added participants can participate\"\xa9\x01\n\x11ParticipationMode\x12\x1e\n\x1aPARTICIPATION_MODE_UNKNOWN\x10\x00\x12\x34\n\x06ONLINE\x10\x01\x1a(\x9a\xf0\xf0\xe4\x01\"everyone start and finish together\x12>\n\x07VIRTUAL\x10\x02\x1a\x31\x9a\xf0\xf0\xe4\x01+participants can start contest individually\"\xc9\x01\n\x12NotificationStatus\x12\x1f\n\x1bNOTIFICATION_STATUS_UNKNOWN\x10\x00\x12\x36\n\x07PENDING\x10\x01\x1a)\x9a\xf0\xf0\xe4\x01#notification are pending to be send\x12,\n\x04SENT\x10\x02\x1a\"\x9a\xf0\xf0\xe4\x01\x1cnotifications have been sent\x12,\n\x08\x44ISABLED\x10\x03\x1a\x1e\x9a\xf0\xf0\xe4\x01\x18notification is disabled\"/\n\x06\x46ormat\x12\x12\n\x0e\x46ORMAT_UNKNOWN\x10\x00\x12\x07\n\x03IOI\x10\x01\x12\x08\n\x04ICPC\x10\x02\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.contest_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_CONTEST_SCOREBOARDCONFIG_VISIBILITY'].values_by_name["INVISIBLE"]._loaded_options = None
  _globals['_CONTEST_SCOREBOARDCONFIG_VISIBILITY'].values_by_name["INVISIBLE"]._serialized_options = b'\232\360\360\344\001\032visible only to organizers'
  _globals['_CONTEST_SCOREBOARDCONFIG_VISIBILITY'].values_by_name["INTERNAL"]._loaded_options = None
  _globals['_CONTEST_SCOREBOARDCONFIG_VISIBILITY'].values_by_name["INTERNAL"]._serialized_options = b'\232\360\360\344\001&visible to participants and organizers'
  _globals['_CONTEST_SCOREBOARDCONFIG_VISIBILITY'].values_by_name["PUBLIC"]._loaded_options = None
  _globals['_CONTEST_SCOREBOARDCONFIG_VISIBILITY'].values_by_name["PUBLIC"]._serialized_options = b'\232\360\360\344\001\023visible to everyone'
  _globals['_CONTEST_STATUS'].values_by_name["SCHEDULED"]._loaded_options = None
  _globals['_CONTEST_STATUS'].values_by_name["SCHEDULED"]._serialized_options = b'\232\360\360\344\001\032contest hasn\'t started yet'
  _globals['_CONTEST_STATUS'].values_by_name["OPEN"]._loaded_options = None
  _globals['_CONTEST_STATUS'].values_by_name["OPEN"]._serialized_options = b'\232\360\360\344\0011contest has started, participants can participate'
  _globals['_CONTEST_STATUS'].values_by_name["COMPLETE"]._loaded_options = None
  _globals['_CONTEST_STATUS'].values_by_name["COMPLETE"]._serialized_options = b'\232\360\360\344\001\023contest is finished'
  _globals['_CONTEST_STATUS'].values_by_name["SUSPENDED"]._loaded_options = None
  _globals['_CONTEST_STATUS'].values_by_name["SUSPENDED"]._serialized_options = b'\232\360\360\344\0016contest has been suspended, interface is not available'
  _globals['_CONTEST_STATUS'].values_by_name["FROZEN"]._loaded_options = None
  _globals['_CONTEST_STATUS'].values_by_name["FROZEN"]._serialized_options = b'\232\360\360\344\001Lcontest has been frozen, interface is available but submission is restricted'
  _globals['_CONTEST_STATUS'].values_by_name["FINALIZED"]._loaded_options = None
  _globals['_CONTEST_STATUS'].values_by_name["FINALIZED"]._serialized_options = b'\232\360\360\344\0012complete, results are final and can not be changed'
  _globals['_CONTEST_VISIBILITY'].values_by_name["PUBLIC"]._loaded_options = None
  _globals['_CONTEST_VISIBILITY'].values_by_name["PUBLIC"]._serialized_options = b'\232\360\360\344\001,visible to everyone and shown on the website'
  _globals['_CONTEST_VISIBILITY'].values_by_name["UNLISTED"]._loaded_options = None
  _globals['_CONTEST_VISIBILITY'].values_by_name["UNLISTED"]._serialized_options = b'\232\360\360\344\0014anyone can participate, but not shown on the website'
  _globals['_CONTEST_VISIBILITY'].values_by_name["PRIVATE"]._loaded_options = None
  _globals['_CONTEST_VISIBILITY'].values_by_name["PRIVATE"]._serialized_options = b'\232\360\360\344\0012only explicitly added participants can participate'
  _globals['_CONTEST_PARTICIPATIONMODE'].values_by_name["ONLINE"]._loaded_options = None
  _globals['_CONTEST_PARTICIPATIONMODE'].values_by_name["ONLINE"]._serialized_options = b'\232\360\360\344\001\"everyone start and finish together'
  _globals['_CONTEST_PARTICIPATIONMODE'].values_by_name["VIRTUAL"]._loaded_options = None
  _globals['_CONTEST_PARTICIPATIONMODE'].values_by_name["VIRTUAL"]._serialized_options = b'\232\360\360\344\001+participants can start contest individually'
  _globals['_CONTEST_NOTIFICATIONSTATUS'].values_by_name["PENDING"]._loaded_options = None
  _globals['_CONTEST_NOTIFICATIONSTATUS'].values_by_name["PENDING"]._serialized_options = b'\232\360\360\344\001#notification are pending to be send'
  _globals['_CONTEST_NOTIFICATIONSTATUS'].values_by_name["SENT"]._loaded_options = None
  _globals['_CONTEST_NOTIFICATIONSTATUS'].values_by_name["SENT"]._serialized_options = b'\232\360\360\344\001\034notifications have been sent'
  _globals['_CONTEST_NOTIFICATIONSTATUS'].values_by_name["DISABLED"]._loaded_options = None
  _globals['_CONTEST_NOTIFICATIONSTATUS'].values_by_name["DISABLED"]._serialized_options = b'\232\360\360\344\001\030notification is disabled'
  _globals['_CONTEST'].fields_by_name['id']._loaded_options = None
  _globals['_CONTEST'].fields_by_name['id']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_CONTEST'].fields_by_name['url']._loaded_options = None
  _globals['_CONTEST'].fields_by_name['url']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_CONTEST'].fields_by_name['status']._loaded_options = None
  _globals['_CONTEST'].fields_by_name['status']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_CONTEST'].fields_by_name['problem_count']._loaded_options = None
  _globals['_CONTEST'].fields_by_name['problem_count']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_CONTEST'].fields_by_name['problem_count_hidden']._loaded_options = None
  _globals['_CONTEST'].fields_by_name['problem_count_hidden']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_CONTEST'].fields_by_name['participant_count']._loaded_options = None
  _globals['_CONTEST'].fields_by_name['participant_count']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_CONTEST'].fields_by_name['participant_count_hidden']._loaded_options = None
  _globals['_CONTEST'].fields_by_name['participant_count_hidden']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_CONTEST'].fields_by_name['printer_id']._loaded_options = None
  _globals['_CONTEST'].fields_by_name['printer_id']._serialized_options = b'\260\360\360\344\001\001'
  _globals['_CONTEST'].fields_by_name['reminder_notification_status']._loaded_options = None
  _globals['_CONTEST'].fields_by_name['reminder_notification_status']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_CONTEST'].fields_by_name['result_notification_status']._loaded_options = None
  _globals['_CONTEST'].fields_by_name['result_notification_status']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_CONTEST'].fields_by_name['staff']._loaded_options = None
  _globals['_CONTEST'].fields_by_name['staff']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_CONTEST']._serialized_start=138
  _globals['_CONTEST']._serialized_end=4613
  _globals['_CONTEST_PATCH']._serialized_start=1671
  _globals['_CONTEST_PATCH']._serialized_end=2260
  _globals['_CONTEST_PATCH_FIELD']._serialized_start=1681
  _globals['_CONTEST_PATCH_FIELD']._serialized_end=2260
  _globals['_CONTEST_EXTRA']._serialized_start=2263
  _globals['_CONTEST_EXTRA']._serialized_end=2439
  _globals['_CONTEST_EXTRA_FIELD']._serialized_start=2273
  _globals['_CONTEST_EXTRA_FIELD']._serialized_end=2439
  _globals['_CONTEST_CLASSIFICATION']._serialized_start=2442
  _globals['_CONTEST_CLASSIFICATION']._serialized_end=2700
  _globals['_CONTEST_CLASSIFICATION_SCALE']._serialized_start=2616
  _globals['_CONTEST_CLASSIFICATION_SCALE']._serialized_end=2700
  _globals['_CONTEST_SCOREBOARDCONFIG']._serialized_start=2703
  _globals['_CONTEST_SCOREBOARDCONFIG']._serialized_end=3114
  _globals['_CONTEST_SCOREBOARDCONFIG_VISIBILITY']._serialized_start=2930
  _globals['_CONTEST_SCOREBOARDCONFIG_VISIBILITY']._serialized_end=3114
  _globals['_CONTEST_RATINGCONFIG']._serialized_start=3116
  _globals['_CONTEST_RATINGCONFIG']._serialized_end=3165
  _globals['_CONTEST_CERTIFICATIONCONFIG']._serialized_start=3168
  _globals['_CONTEST_CERTIFICATIONCONFIG']._serialized_end=3333
  _globals['_CONTEST_CERTIFICATIONCONFIG_SIGNER']._serialized_start=3296
  _globals['_CONTEST_CERTIFICATIONCONFIG_SIGNER']._serialized_end=3333
  _globals['_CONTEST_ENVIRONMENTCONFIG']._serialized_start=3335
  _globals['_CONTEST_ENVIRONMENTCONFIG']._serialized_end=3397
  _globals['_CONTEST_PLAGIARISMCONFIG']._serialized_start=3399
  _globals['_CONTEST_PLAGIARISMCONFIG']._serialized_end=3442
  _globals['_CONTEST_STAFF']._serialized_start=3444
  _globals['_CONTEST_STAFF']._serialized_end=3506
  _globals['_CONTEST_STATUS']._serialized_start=3509
  _globals['_CONTEST_STATUS']._serialized_end=3940
  _globals['_CONTEST_VISIBILITY']._serialized_start=3943
  _globals['_CONTEST_VISIBILITY']._serialized_end=4188
  _globals['_CONTEST_PARTICIPATIONMODE']._serialized_start=4191
  _globals['_CONTEST_PARTICIPATIONMODE']._serialized_end=4360
  _globals['_CONTEST_NOTIFICATIONSTATUS']._serialized_start=4363
  _globals['_CONTEST_NOTIFICATIONSTATUS']._serialized_end=4564
  _globals['_CONTEST_FORMAT']._serialized_start=4566
  _globals['_CONTEST_FORMAT']._serialized_end=4613
# @@protoc_insertion_point(module_scope)



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Invoice(_message.Message):
    __slots__ = ("id", "number", "currency", "status", "status_reason", "vendor_id", "payment_method_id", "invoice_date", "due_date", "lines", "subtotal_amount", "tax_amount", "grand_total", "document_url", "created_at", "updated_at")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[Invoice.Status]
        DRAFT: _ClassVar[Invoice.Status]
        PENDING: _ClassVar[Invoice.Status]
        APPROVED: _ClassVar[Invoice.Status]
        PAID: _ClassVar[Invoice.Status]
        REJECTED: _ClassVar[Invoice.Status]
    UNKNOWN_STATUS: Invoice.Status
    DRAFT: Invoice.Status
    PENDING: Invoice.Status
    APPROVED: Invoice.Status
    PAID: Invoice.Status
    REJECTED: Invoice.Status
    class Line(_message.Message):
        __slots__ = ("index", "name", "summary", "total_price")
        INDEX_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        SUMMARY_FIELD_NUMBER: _ClassVar[int]
        TOTAL_PRICE_FIELD_NUMBER: _ClassVar[int]
        index: int
        name: str
        summary: str
        total_price: int
        def __init__(self, index: _Optional[int] = ..., name: _Optional[str] = ..., summary: _Optional[str] = ..., total_price: _Optional[int] = ...) -> None: ...
    class Patch(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_FIELD: _ClassVar[Invoice.Patch.Field]
            NUMBER: _ClassVar[Invoice.Patch.Field]
            CURRENCY: _ClassVar[Invoice.Patch.Field]
            INVOICE_DATE: _ClassVar[Invoice.Patch.Field]
            DUE_DATE: _ClassVar[Invoice.Patch.Field]
            LINES: _ClassVar[Invoice.Patch.Field]
            PAYMENT_METHOD: _ClassVar[Invoice.Patch.Field]
        UNKNOWN_FIELD: Invoice.Patch.Field
        NUMBER: Invoice.Patch.Field
        CURRENCY: Invoice.Patch.Field
        INVOICE_DATE: Invoice.Patch.Field
        DUE_DATE: Invoice.Patch.Field
        LINES: Invoice.Patch.Field
        PAYMENT_METHOD: Invoice.Patch.Field
        def __init__(self) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    STATUS_REASON_FIELD_NUMBER: _ClassVar[int]
    VENDOR_ID_FIELD_NUMBER: _ClassVar[int]
    PAYMENT_METHOD_ID_FIELD_NUMBER: _ClassVar[int]
    INVOICE_DATE_FIELD_NUMBER: _ClassVar[int]
    DUE_DATE_FIELD_NUMBER: _ClassVar[int]
    LINES_FIELD_NUMBER: _ClassVar[int]
    SUBTOTAL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    TAX_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    GRAND_TOTAL_FIELD_NUMBER: _ClassVar[int]
    DOCUMENT_URL_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    number: str
    currency: str
    status: Invoice.Status
    status_reason: str
    vendor_id: str
    payment_method_id: str
    invoice_date: _timestamp_pb2.Timestamp
    due_date: _timestamp_pb2.Timestamp
    lines: _containers.RepeatedCompositeFieldContainer[Invoice.Line]
    subtotal_amount: int
    tax_amount: int
    grand_total: int
    document_url: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., number: _Optional[str] = ..., currency: _Optional[str] = ..., status: _Optional[_Union[Invoice.Status, str]] = ..., status_reason: _Optional[str] = ..., vendor_id: _Optional[str] = ..., payment_method_id: _Optional[str] = ..., invoice_date: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., due_date: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., lines: _Optional[_Iterable[_Union[Invoice.Line, _Mapping]]] = ..., subtotal_amount: _Optional[int] = ..., tax_amount: _Optional[int] = ..., grand_total: _Optional[int] = ..., document_url: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/course/student_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/course/student_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import namespace_pb2 as eolymp_dot_annotations_dot_namespace__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import assignment_pb2 as eolymp_dot_course_dot_assignment__pb2
from eolymp.course import material_pb2 as eolymp_dot_course_dot_material__pb2
from eolymp.course import module_pb2 as eolymp_dot_course_dot_module__pb2
from eolymp.course import student_pb2 as eolymp_dot_course_dot_student__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/course/student_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/namespace.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1e\x65olymp/course/assignment.proto\x1a\x1c\x65olymp/course/material.proto\x1a\x1a\x65olymp/course/module.proto\x1a\x1b\x65olymp/course/student.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"=\n\x12\x43reateStudentInput\x12\'\n\x07student\x18\x01 \x01(\x0b\x32\x16.eolymp.course.Student\")\n\x13\x43reateStudentOutput\x12\x12\n\nstudent_id\x18\x02 \x01(\t\"\xb8\x01\n\x12UpdateStudentInput\x12\x36\n\x05patch\x18\x01 \x03(\x0e\x32\'.eolymp.course.UpdateStudentInput.Patch\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\'\n\x07student\x18\x03 \x01(\x0b\x32\x16.eolymp.course.Student\".\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0c\n\x08INACTIVE\x10\x01\x12\x0e\n\nASSIGN_ALL\x10\x02\"\x15\n\x13UpdateStudentOutput\"\'\n\x12\x44\x65leteStudentInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteStudentOutput\"W\n\x14\x44\x65scribeStudentInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12,\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1c.eolymp.course.Student.Extra\"@\n\x15\x44\x65scribeStudentOutput\x12\'\n\x07student\x18\x01 \x01(\x0b\x32\x16.eolymp.course.Student\"\xd2\x03\n\x11ListStudentsInput\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.course.ListStudentsInput.Filter\x12\x37\n\x04sort\x18\x32 \x01(\x0e\x32).eolymp.course.ListStudentsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12,\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1c.eolymp.course.Student.Extra\x1a\x99\x01\n\x06\x46ilter\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x0b \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08group_id\x18\x0c \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"\x17\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\"d\n\x12ListStudentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.course.Student\x12\x18\n\x10next_page_cursor\x18\x03 \x01(\t\"T\n\x11WatchStudentInput\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12,\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1c.eolymp.course.Student.Extra\"=\n\x12WatchStudentOutput\x12\'\n\x07student\x18\x01 \x01(\x0b\x32\x16.eolymp.course.Student\"\x11\n\x0fJoinCourseInput\"\x12\n\x10JoinCourseOutput\"C\n\x13\x44\x65scribeViewerInput\x12,\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1c.eolymp.course.Student.Extra\"?\n\x14\x44\x65scribeViewerOutput\x12\'\n\x07student\x18\x01 \x01(\x0b\x32\x16.eolymp.course.Student\"\x8b\x02\n\x1bListStudentAssignmentsInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12\x42\n\x07\x66ilters\x18( \x01(\x0b\x32\x31.eolymp.course.ListStudentAssignmentsInput.Filter\x1ag\n\x06\x46ilter\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmodule_id\x18\x0b \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"W\n\x1cListStudentAssignmentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.course.Assignment\"\xcd\x01\n\x1cUpdateStudentAssignmentInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12/\n\x0bstart_after\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x63omplete_before\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x64uration\x18\r \x01(\r\x12\x0f\n\x07upsolve\x18\x1e \x01(\x08\"\x1f\n\x1dUpdateStudentAssignmentOutput\"D\n\x1c\x44\x65leteStudentAssignmentInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\t\"\x1f\n\x1d\x44\x65leteStudentAssignmentOutput\"+\n\x16ListStudentGradesInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"H\n\x17ListStudentGradesOutput\x12-\n\x05items\x18\x01 \x03(\x0b\x32\x1e.eolymp.course.Module.Progress\"=\n\x15ListModuleGradesInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\t\"I\n\x16ListModuleGradesOutput\x12/\n\x05items\x18\x01 \x03(\x0b\x32 .eolymp.course.Material.Progress2\xa7\x11\n\x0eStudentService\x12\x93\x01\n\rCreateStudent\x12!.eolymp.course.CreateStudentInput\x1a\".eolymp.course.CreateStudentOutput\";\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\x0b\"\t/students\x12\x9f\x01\n\rUpdateStudent\x12!.eolymp.course.UpdateStudentInput\x1a\".eolymp.course.UpdateStudentOutput\"G\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\x17\"\x15/students/{member_id}\x12\x9f\x01\n\rDeleteStudent\x12!.eolymp.course.DeleteStudentInput\x1a\".eolymp.course.DeleteStudentOutput\"G\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\x17*\x15/students/{member_id}\x12\xa4\x01\n\x0f\x44\x65scribeStudent\x12#.eolymp.course.DescribeStudentInput\x1a$.eolymp.course.DescribeStudentOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x17\x12\x15/students/{member_id}\x12\x8f\x01\n\x0cListStudents\x12 .eolymp.course.ListStudentsInput\x1a!.eolymp.course.ListStudentsOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x0b\x12\t/students\x12q\n\x0cWatchStudent\x12 .eolymp.course.WatchStudentInput\x1a!.eolymp.course.WatchStudentOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read0\x01\x12\x85\x01\n\nJoinCourse\x12\x1e.eolymp.course.JoinCourseInput\x1a\x1f.eolymp.course.JoinCourseOutput\"6\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x07\"\x05/join\x12\x9b\x01\n\x0e\x44\x65scribeViewer\x12\".eolymp.course.DescribeViewerInput\x1a#.eolymp.course.DescribeViewerOutput\"@\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x11\x12\x0f/viewer/student\x12\xc5\x01\n\x16ListStudentAssignments\x12*.eolymp.course.ListStudentAssignmentsInput\x1a+.eolymp.course.ListStudentAssignmentsOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02#\x12!/students/{member_id}/assignments\x12\xc8\x01\n\x17UpdateStudentAssignment\x12+.eolymp.course.UpdateStudentAssignmentInput\x1a,.eolymp.course.UpdateStudentAssignmentOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02#\"!/students/{member_id}/assignments\x12\xc8\x01\n\x17\x44\x65leteStudentAssignment\x12+.eolymp.course.DeleteStudentAssignmentInput\x1a,.eolymp.course.DeleteStudentAssignmentOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02#*!/students/{member_id}/assignments\x12\xb1\x01\n\x11ListStudentGrades\x12%.eolymp.course.ListStudentGradesInput\x1a&.eolymp.course.ListStudentGradesOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x1e\x12\x1c/students/{member_id}/grades\x12\xba\x01\n\x10ListModuleGrades\x12$.eolymp.course.ListModuleGradesInput\x1a%.eolymp.course.ListModuleGradesOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02*\x12(/students/{member_id}/grades/{module_id}\x1a\x1a\x82\xf0\xf0\xe4\x01\x14\x65olymp.course.CourseB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.student_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _globals['_STUDENTSERVICE']._loaded_options = None
  _globals['_STUDENTSERVICE']._serialized_options = b'\202\360\360\344\001\024eolymp.course.Course'
  _globals['_STUDENTSERVICE'].methods_by_name['CreateStudent']._loaded_options = None
  _globals['_STUDENTSERVICE'].methods_by_name['CreateStudent']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\013\"\t/students'
  _globals['_STUDENTSERVICE'].methods_by_name['UpdateStudent']._loaded_options = None
  _globals['_STUDENTSERVICE'].methods_by_name['UpdateStudent']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\027\"\025/students/{member_id}'
  _globals['_STUDENTSERVICE'].methods_by_name['DeleteStudent']._loaded_options = None
  _globals['_STUDENTSERVICE'].methods_by_name['DeleteStudent']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\027*\025/students/{member_id}'
  _globals['_STUDENTSERVICE'].methods_by_name['DescribeStudent']._loaded_options = None
  _globals['_STUDENTSERVICE'].methods_by_name['DescribeStudent']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\027\022\025/students/{member_id}'
  _globals['_STUDENTSERVICE'].methods_by_name['ListStudents']._loaded_options = None
  _globals['_STUDENTSERVICE'].methods_by_name['ListStudents']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\013\022\t/students'
  _globals['_STUDENTSERVICE'].methods_by_name['WatchStudent']._loaded_options = None
  _globals['_STUDENTSERVICE'].methods_by_name['WatchStudent']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read'
  _globals['_STUDENTSERVICE'].methods_by_name['JoinCourse']._loaded_options = None
  _globals['_STUDENTSERVICE'].methods_by_name['JoinCourse']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\007\"\005/join'
  _globals['_STUDENTSERVICE'].methods_by_name['DescribeViewer']._loaded_options = None
  _globals['_STUDENTSERVICE'].methods_by_name['DescribeViewer']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\021\022\017/viewer/student'
  _globals['_STUDENTSERVICE'].methods_by_name['ListStudentAssignments']._loaded_options = None
  _globals['_STUDENTSERVICE'].methods_by_name['ListStudentAssignments']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002#\022!/students/{member_id}/assignments'
  _globals['_STUDENTSERVICE'].methods_by_name['UpdateStudentAssignment']._loaded_options = None
  _globals['_STUDENTSERVICE'].methods_by_name['UpdateStudentAssignment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002#\"!/students/{member_id}/assignments'
  _globals['_STUDENTSERVICE'].methods_by_name['DeleteStudentAssignment']._loaded_options = None
  _globals['_STUDENTSERVICE'].methods_by_name['DeleteStudentAssignment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002#*!/students/{member_id}/assignments'
  _globals['_STUDENTSERVICE'].methods_by_name['ListStudentGrades']._loaded_options = None
  _globals['_STUDENTSERVICE'].methods_by_name['ListStudentGrades']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\036\022\034/students/{member_id}/grades'
  _globals['_STUDENTSERVICE'].methods_by_name['ListModuleGrades']._loaded_options = None
  _globals['_STUDENTSERVICE'].methods_by_name['ListModuleGrades']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002*\022(/students/{member_id}/grades/{module_id}'
  _globals['_CREATESTUDENTINPUT']._serialized_start=410
  _globals['_CREATESTUDENTINPUT']._serialized_end=471
  _globals['_CREATESTUDENTOUTPUT']._serialized_start=473
  _globals['_CREATESTUDENTOUTPUT']._serialized_end=514
  _globals['_UPDATESTUDENTINPUT']._serialized_start=517
  _globals['_UPDATESTUDENTINPUT']._serialized_end=701
  _globals['_UPDATESTUDENTINPUT_PATCH']._serialized_start=655
  _globals['_UPDATESTUDENTINPUT_PATCH']._serialized_end=701
  _globals['_UPDATESTUDENTOUTPUT']._serialized_start=703
  _globals['_UPDATESTUDENTOUTPUT']._serialized_end=724
  _globals['_DELETESTUDENTINPUT']._serialized_start=726
  _globals['_DELETESTUDENTINPUT']._serialized_end=765
  _globals['_DELETESTUDENTOUTPUT']._serialized_start=767
  _globals['_DELETESTUDENTOUTPUT']._serialized_end=788
  _globals['_DESCRIBESTUDENTINPUT']._serialized_start=790
  _globals['_DESCRIBESTUDENTINPUT']._serialized_end=877
  _globals['_DESCRIBESTUDENTOUTPUT']._serialized_start=879
  _globals['_DESCRIBESTUDENTOUTPUT']._serialized_end=943
  _globals['_LISTSTUDENTSINPUT']._serialized_start=946
  _globals['_LISTSTUDENTSINPUT']._serialized_end=1412
  _globals['_LISTSTUDENTSINPUT_FILTER']._serialized_start=1234
  _globals['_LISTSTUDENTSINPUT_FILTER']._serialized_end=1387
  _globals['_LISTSTUDENTSINPUT_SORTABLE']._serialized_start=1389
  _globals['_LISTSTUDENTSINPUT_SORTABLE']._serialized_end=1412
  _globals['_LISTSTUDENTSOUTPUT']._serialized_start=1414
  _globals['_LISTSTUDENTSOUTPUT']._serialized_end=1514
  _globals['_WATCHSTUDENTINPUT']._serialized_start=1516
  _globals['_WATCHSTUDENTINPUT']._serialized_end=1600
  _globals['_WATCHSTUDENTOUTPUT']._serialized_start=1602
  _globals['_WATCHSTUDENTOUTPUT']._serialized_end=1663
  _globals['_JOINCOURSEINPUT']._serialized_start=1665
  _globals['_JOINCOURSEINPUT']._serialized_end=1682
  _globals['_JOINCOURSEOUTPUT']._serialized_start=1684
  _globals['_JOINCOURSEOUTPUT']._serialized_end=1702
  _globals['_DESCRIBEVIEWERINPUT']._serialized_start=1704
  _globals['_DESCRIBEVIEWERINPUT']._serialized_end=1771
  _globals['_DESCRIBEVIEWEROUTPUT']._serialized_start=1773
  _globals['_DESCRIBEVIEWEROUTPUT']._serialized_end=1836
  _globals['_LISTSTUDENTASSIGNMENTSINPUT']._serialized_start=1839
  _globals['_LISTSTUDENTASSIGNMENTSINPUT']._serialized_end=2106
  _globals['_LISTSTUDENTASSIGNMENTSINPUT_FILTER']._serialized_start=2003
  _globals['_LISTSTUDENTASSIGNMENTSINPUT_FILTER']._serialized_end=2106
  _globals['_LISTSTUDENTASSIGNMENTSOUTPUT']._serialized_start=2108
  _globals['_LISTSTUDENTASSIGNMENTSOUTPUT']._serialized_end=2195
  _globals['_UPDATESTUDENTASSIGNMENTINPUT']._serialized_start=2198
  _globals['_UPDATESTUDENTASSIGNMENTINPUT']._serialized_end=2403
  _globals['_UPDATESTUDENTASSIGNMENTOUTPUT']._serialized_start=2405
  _globals['_UPDATESTUDENTASSIGNMENTOUTPUT']._serialized_end=2436
  _globals['_DELETESTUDENTASSIGNMENTINPUT']._serialized_start=2438
  _globals['_DELETESTUDENTASSIGNMENTINPUT']._serialized_end=2506
  _globals['_DELETESTUDENTASSIGNMENTOUTPUT']._serialized_start=2508
  _globals['_DELETESTUDENTASSIGNMENTOUTPUT']._serialized_end=2539
  _globals['_LISTSTUDENTGRADESINPUT']._serialized_start=2541
  _globals['_LISTSTUDENTGRADESINPUT']._serialized_end=2584
  _globals['_LISTSTUDENTGRADESOUTPUT']._serialized_start=2586
  _globals['_LISTSTUDENTGRADESOUTPUT']._serialized_end=2658
  _globals['_LISTMODULEGRADESINPUT']._serialized_start=2660
  _globals['_LISTMODULEGRADESINPUT']._serialized_end=2721
  _globals['_LISTMODULEGRADESOUTPUT']._serialized_start=2723
  _globals['_LISTMODULEGRADESOUTPUT']._serialized_end=2796
  _globals['_STUDENTSERVICE']._serialized_start=2799
  _globals['_STUDENTSERVICE']._serialized_end=5014
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class InvoiceServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def ListInvoices(self, request, **kwargs):
        path = "/vendor/invoices"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.vendor.ListInvoicesOutput"),
            **kwargs,
        )

    def DescribeInvoice(self, request, **kwargs):
        path = "/vendor/invoices/"+urllib.parse.quote(request.invoice_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.invoice_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.vendor.DescribeInvoiceOutput"),
            **kwargs,
        )

    def CreateInvoice(self, request, **kwargs):
        path = "/vendor/invoices"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.vendor.CreateInvoiceOutput"),
            **kwargs,
        )

    def UpdateInvoice(self, request, **kwargs):
        path = "/vendor/invoices/"+urllib.parse.quote(request.invoice_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.invoice_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.vendor.UpdateInvoiceOutput"),
            **kwargs,
        )

    def DeleteInvoice(self, request, **kwargs):
        path = "/vendor/invoices/"+urllib.parse.quote(request.invoice_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.invoice_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.vendor.DeleteInvoiceOutput"),
            **kwargs,
        )

    def UploadInvoiceDocument(self, request, **kwargs):
        path = "/vendor/invoices/"+urllib.parse.quote(request.invoice_id)+"/document"

        # Cleanup URL parameters to avoid any ambiguity
        request.invoice_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.vendor.UploadInvoiceDocumentOutput"),
            **kwargs,
        )

    def SubmitInvoice(self, request, **kwargs):
        path = "/vendor/invoices/"+urllib.parse.quote(request.invoice_id)+"/submit"

        # Cleanup URL parameters to avoid any ambiguity
        request.invoice_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.vendor.SubmitInvoiceOutput"),
            **kwargs,
        )

    def ApproveInvoice(self, request, **kwargs):
        path = "/vendor/invoices/"+urllib.parse.quote(request.invoice_id)+"/approve"

        # Cleanup URL parameters to avoid any ambiguity
        request.invoice_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.vendor.ApproveInvoiceOutput"),
            **kwargs,
        )

    def RejectInvoice(self, request, **kwargs):
        path = "/vendor/invoices/"+urllib.parse.quote(request.invoice_id)+"/reject"

        # Cleanup URL parameters to avoid any ambiguity
        request.invoice_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.vendor.RejectInvoiceOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/auth/client.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/auth/client.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x65olymp/auth/client.proto\x12\x0b\x65olymp.auth\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe9\x01\n\x06\x43lient\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0credirect_uri\x18\x04 \x03(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a?\n\x05Patch\"6\n\x05\x46ield\x12\x11\n\rUNKNOWN_FIELD\x10\x00\x12\x08\n\x04NAME\x10\x02\x12\x10\n\x0cREDIRECT_URI\x10\x03\x42+Z)github.com/eolymp/go-sdk/eolymp/auth;authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.auth.client_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/auth;auth'
  _globals['_CLIENT']._serialized_start=75
  _globals['_CLIENT']._serialized_end=308
  _globals['_CLIENT_PATCH']._serialized_start=245
  _globals['_CLIENT_PATCH']._serialized_end=308
  _globals['_CLIENT_PATCH_FIELD']._serialized_start=254
  _globals['_CLIENT_PATCH_FIELD']._serialized_end=308
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/problem.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/atlas/problem.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import mcp_pb2 as eolymp_dot_annotations_dot_mcp__pb2
from eolymp.atlas import form_pb2 as eolymp_dot_atlas_dot_form__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/atlas/problem.proto\x12\x0c\x65olymp.atlas\x1a\x1c\x65olymp/annotations/mcp.proto\x1a\x17\x65olymp/atlas/form.proto\x1a\x18\x65olymp/ecm/content.proto\"\xa3\x0c\n\x07Problem\x12\x12\n\x02id\x18\x01 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x14\n\x03url\x18\xaa\x05 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12(\n\x04type\x18\x17 \x01(\x0e\x32\x1a.eolymp.atlas.Problem.Type\x12\x0e\n\x06number\x18\n \x01(\x05\x12\x0f\n\x07visible\x18\x0b \x01(\x08\x12\x0e\n\x06origin\x18\r \x01(\t\x12\x18\n\x08language\x18\x03 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x15\n\x05title\x18\x04 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12,\n\x07\x63ontent\x18\x06 \x01(\x0b\x32\x13.eolymp.ecm.ContentB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x1d\n\rdownload_link\x18\x07 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x16\n\x06\x61uthor\x18\x65 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x16\n\x06source\x18\x66 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x11\n\tlanguages\x18g \x03(\t\x12\x0e\n\x06topics\x18\x14 \x03(\t\x12\x15\n\x05score\x18\x1f \x01(\x02\x42\x06\xa8\xf0\xf0\xe4\x01\x01\x12>\n\x0b\x63onstraints\x18\x1e \x01(\x0b\x32!.eolymp.atlas.Problem.ConstraintsB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x1f\n\x0f\x61\x63\x63\x65ptance_rate\x18( \x01(\x02\x42\x06\xa8\xf0\xf0\xe4\x01\x01\x12!\n\x11submissions_count\x18* \x01(\rB\x06\xa8\xf0\xf0\xe4\x01\x01\x12$\n\x14submissions_accepted\x18+ \x01(\rB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x14\n\x04vote\x18\x32 \x01(\x05\x42\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x1a\n\nvote_count\x18\x33 \x01(\x05\x42\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x12\n\ndifficulty\x18\x15 \x01(\r\x12\x33\n\x0fsubmission_form\x18\x16 \x01(\x0b\x32\x12.eolymp.atlas.FormB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x37\n\x08\x65xamples\x18< \x03(\x0b\x32\x1d.eolymp.atlas.Problem.ExampleB\x06\xa8\xf0\xf0\xe4\x01\x01\x1as\n\x05\x45xtra\"j\n\x05\x46ield\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x32\n\rCONTENT_VALUE\x10\x03\x1a\x1f\x9a\xf0\xf0\xe4\x01\x19include problem statement\x12\x1a\n\x0e\x43ONTENT_RENDER\x10\x04\x1a\x06\xb8\xf0\xf0\xe4\x01\x01\x1a{\n\x05Patch\"r\n\x05\x46ield\x12\x11\n\rUNKNOWN_PATCH\x10\x00\x12\x0b\n\x07VISIBLE\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\x12\n\n\x06TOPICS\x10\x03\x12\x0e\n\nDIFFICULTY\x10\x04\x12\n\n\x06ORIGIN\x10\x05\x12\x08\n\x04TYPE\x10\x06\x12\n\n\x06NUMBER\x10\x07\x1a\x9f\x01\n\x0b\x43onstraints\x12\x16\n\x0etime_limit_min\x18< \x01(\r\x12\x16\n\x0etime_limit_max\x18= \x01(\r\x12\x15\n\rcpu_limit_min\x18> \x01(\r\x12\x15\n\rcpu_limit_max\x18? \x01(\r\x12\x18\n\x10memory_limit_min\x18@ \x01(\x04\x12\x18\n\x10memory_limit_max\x18\x41 \x01(\x04\x1a?\n\x07\x45xample\x12\r\n\x05index\x18\x01 \x01(\r\x12\x11\n\tinput_url\x18\x02 \x01(\t\x12\x12\n\nanswer_url\x18\x03 \x01(\t\"\xf7\x02\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12K\n\x07PROGRAM\x10\x01\x1a>\x9a\xf0\xf0\xe4\x01\x38program problem, user should write a program to solve it\x12N\n\x08\x46UNCTION\x10\x02\x1a@\x9a\xf0\xf0\xe4\x01:function problem, user should write a function to solve it\x12Q\n\x06OUTPUT\x10\x03\x1a\x45\x9a\xf0\xf0\xe4\x01?output-only problem, user should upload answer file to solve it\x12\x45\n\x03SQL\x10\x04\x1a<\x9a\xf0\xf0\xe4\x01\x36SQL problem, user should write SQL queries to solve it\x12&\n\x02ML\x10\x05\x1a\x1e\x9a\xf0\xf0\xe4\x01\x18Machine learning problemB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.problem_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_PROBLEM_EXTRA_FIELD'].values_by_name["CONTENT_VALUE"]._loaded_options = None
  _globals['_PROBLEM_EXTRA_FIELD'].values_by_name["CONTENT_VALUE"]._serialized_options = b'\232\360\360\344\001\031include problem statement'
  _globals['_PROBLEM_EXTRA_FIELD'].values_by_name["CONTENT_RENDER"]._loaded_options = None
  _globals['_PROBLEM_EXTRA_FIELD'].values_by_name["CONTENT_RENDER"]._serialized_options = b'\270\360\360\344\001\001'
  _globals['_PROBLEM_TYPE'].values_by_name["PROGRAM"]._loaded_options = None
  _globals['_PROBLEM_TYPE'].values_by_name["PROGRAM"]._serialized_options = b'\232\360\360\344\0018program problem, user should write a program to solve it'
  _globals['_PROBLEM_TYPE'].values_by_name["FUNCTION"]._loaded_options = None
  _globals['_PROBLEM_TYPE'].values_by_name["FUNCTION"]._serialized_options = b'\232\360\360\344\001:function problem, user should write a function to solve it'
  _globals['_PROBLEM_TYPE'].values_by_name["OUTPUT"]._loaded_options = None
  _globals['_PROBLEM_TYPE'].values_by_name["OUTPUT"]._serialized_options = b'\232\360\360\344\001?output-only problem, user should upload answer file to solve it'
  _globals['_PROBLEM_TYPE'].values_by_name["SQL"]._loaded_options = None
  _globals['_PROBLEM_TYPE'].values_by_name["SQL"]._serialized_options = b'\232\360\360\344\0016SQL problem, user should write SQL queries to solve it'
  _globals['_PROBLEM_TYPE'].values_by_name["ML"]._loaded_options = None
  _globals['_PROBLEM_TYPE'].values_by_name["ML"]._serialized_options = b'\232\360\360\344\001\030Machine learning problem'
  _globals['_PROBLEM'].fields_by_name['id']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['id']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['url']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['url']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['language']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['language']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['title']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['title']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['content']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['content']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['download_link']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['download_link']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['author']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['author']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['source']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['source']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['score']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['score']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['constraints']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['constraints']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['acceptance_rate']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['acceptance_rate']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['submissions_count']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['submissions_count']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['submissions_accepted']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['submissions_accepted']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['vote']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['vote']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['vote_count']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['vote_count']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['submission_form']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['submission_form']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM'].fields_by_name['examples']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['examples']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_PROBLEM']._serialized_start=126
  _globals['_PROBLEM']._serialized_end=1697
  _globals['_PROBLEM_EXTRA']._serialized_start=852
  _globals['_PROBLEM_EXTRA']._serialized_end=967
  _globals['_PROBLEM_EXTRA_FIELD']._serialized_start=861
  _globals['_PROBLEM_EXTRA_FIELD']._serialized_end=967
  _globals['_PROBLEM_PATCH']._serialized_start=969
  _globals['_PROBLEM_PATCH']._serialized_end=1092
  _globals['_PROBLEM_PATCH_FIELD']._serialized_start=978
  _globals['_PROBLEM_PATCH_FIELD']._serialized_end=1092
  _globals['_PROBLEM_CONSTRAINTS']._serialized_start=1095
  _globals['_PROBLEM_CONSTRAINTS']._serialized_end=1254
  _globals['_PROBLEM_EXAMPLE']._serialized_start=1256
  _globals['_PROBLEM_EXAMPLE']._serialized_end=1319
  _globals['_PROBLEM_TYPE']._serialized_start=1322
  _globals['_PROBLEM_TYPE']._serialized_end=1697
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/universe/space.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/universe/space.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import mcp_pb2 as eolymp_dot_annotations_dot_mcp__pb2
from eolymp.universe import quota_pb2 as eolymp_dot_universe_dot_quota__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/universe/space.proto\x12\x0f\x65olymp.universe\x1a\x1c\x65olymp/annotations/mcp.proto\x1a\x1b\x65olymp/universe/quota.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb2\t\n\x05Space\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x10\n\x08home_url\x18\x32 \x01(\t\x12\x12\n\nissuer_url\x18\x33 \x01(\t\x12\x13\n\x0bgraphql_url\x18\x34 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\r\n\x05image\x18\x0b \x01(\t\x12\x35\n\nvisibility\x18\x0e \x01(\x0e\x32!.eolymp.universe.Space.Visibility\x12\x35\n\x06status\x18\x10 \x01(\x0e\x32\x1d.eolymp.universe.Space.StatusB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x38\n\x08\x66\x65\x61tures\x18\x11 \x03(\x0e\x32\x1e.eolymp.universe.Space.FeatureB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x42\n\x0csubscription\x18\xa0\x06 \x01(\x0b\x32#.eolymp.universe.Space.SubscriptionB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x1b\n\x0b\x61\x66\x66iliation\x18\x0f \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12 \n\x10\x64iscord_guild_id\x18\x12 \x01(\tB\x06\xa8\xf0\xf0\xe4\x01\x01\x12\x0f\n\x07locales\x18\x13 \x03(\t\x1a\x35\n\x05\x45xtra\",\n\x05\x46ield\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x10\n\x0cSUBSCRIPTION\x10\x01\x1a^\n\x05Patch\"U\n\x05\x46ield\x12\x11\n\rUNKNOWN_PATCH\x10\x00\x12\x07\n\x03KEY\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\t\n\x05IMAGE\x10\x03\x12\x0e\n\nVISIBILITY\x10\x05\x12\x0b\n\x07LOCALES\x10\x06\x1a\xde\x02\n\x0cSubscription\x12\x0c\n\x04plan\x18\x01 \x01(\t\x12\r\n\x05seats\x18\x02 \x01(\r\x12\r\n\x05usage\x18\x03 \x01(\r\x12\x1b\n\x13usage_based_billing\x18\x05 \x01(\x08\x12%\n\x05quota\x18\n \x01(\x0b\x32\x16.eolymp.universe.Quota\x12\x38\n\x14\x62illing_period_start\x18Z \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12\x62illing_period_end\x18[ \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12quota_period_start\x18\\ \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10quota_period_end\x18] \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"B\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\t\n\x05TRIAL\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\r\n\tSUSPENDED\x10\x03\"=\n\nVisibility\x12\x16\n\x12UNKNOWN_VISIBILITY\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\"t\n\x07\x46\x65\x61ture\x12\x13\n\x0fUNKNOWN_FEATURE\x10\x00\x12\x0c\n\x08PRINTERS\x10\x01\x12\x0f\n\x0bNEWSLETTERS\x10\x02\x12\x12\n\x0eMEMBER_CREDITS\x10\x03\x12\x15\n\x11MERCHANDISE_STORE\x10\x04\x12\n\n\x06RATING\x10\x05\x42\x33Z1github.com/eolymp/go-sdk/eolymp/universe;universeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.universe.space_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/universe;universe'
  _globals['_SPACE'].fields_by_name['status']._loaded_options = None
  _globals['_SPACE'].fields_by_name['status']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_SPACE'].fields_by_name['features']._loaded_options = None
  _globals['_SPACE'].fields_by_name['features']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_SPACE'].fields_by_name['subscription']._loaded_options = None
  _globals['_SPACE'].fields_by_name['subscription']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_SPACE'].fields_by_name['affiliation']._loaded_options = None
  _globals['_SPACE'].fields_by_name['affiliation']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_SPACE'].fields_by_name['discord_guild_id']._loaded_options = None
  _globals['_SPACE'].fields_by_name['discord_guild_id']._serialized_options = b'\250\360\360\344\001\001'
  _globals['_SPACE']._serialized_start=141
  _globals['_SPACE']._serialized_end=1343
  _globals['_SPACE_EXTRA']._serialized_start=592
  _globals['_SPACE_EXTRA']._serialized_end=645
  _globals['_SPACE_EXTRA_FIELD']._serialized_start=601
  _globals['_SPACE_EXTRA_FIELD']._serialized_end=645
  _globals['_SPACE_PATCH']._serialized_start=647
  _globals['_SPACE_PATCH']._serialized_end=741
  _globals['_SPACE_PATCH_FIELD']._serialized_start=656
  _globals['_SPACE_PATCH_FIELD']._serialized_end=741
  _globals['_SPACE_SUBSCRIPTION']._serialized_start=744
  _globals['_SPACE_SUBSCRIPTION']._serialized_end=1094
  _globals['_SPACE_STATUS']._serialized_start=1096
  _globals['_SPACE_STATUS']._serialized_end=1162
  _globals['_SPACE_VISIBILITY']._serialized_start=1164
  _globals['_SPACE_VISIBILITY']._serialized_end=1225
  _globals['_SPACE_FEATURE']._serialized_start=1227
  _globals['_SPACE_FEATURE']._serialized_end=1343
# @@protoc_insertion_point(module_scope)
